@@ -71,7 +71,7 @@ def check_install_mfa(verbose, force):
             f"conda create -y -n alignments_mfa python={platform.python_version()}", 'creating "alignments_mfa" conda environment', not verbose
         )
         out = run_subprocess(
-            "conda install montreal-forced-aligner -c conda-forge -n alignments_mfa -y",
+            "conda install montreal-forced-aligner=2.0.4 -c conda-forge -n alignments_mfa -y",
             "installing montreal-forced-aligner",
             not verbose,
         )
@@ -134,6 +134,7 @@ class AlignmentDataset(Dataset):
                     tarfile.open(tmp_path).extractall(source_directory)
                 else:
                     raise ValueError("Unknown file type, only .zip and .tar.gz are supported.")
+                shutil.rmtree(download_path, ignore_errors=True)
             else:
                 print("Source directory already exists. Skipping [blue]download[/blue].")
 
@@ -247,6 +248,8 @@ class AlignmentDataset(Dataset):
                 f"cp -rT {target_temp_directory} {target_directory}",
                 "copying TextGrids to target directory",
             )
+            shutil.rmtree(target_temp_directory, ignore_errors=True)
+            shutil.rmtree(os.environ["MFA_ROOT_DIR"], ignore_errors=True)
         else:
             print("TextGrids already exist. Skipping [blue]alignment[/blue].")
 
@@ -384,4 +387,4 @@ class AlignmentDataset(Dataset):
         return self.data[index]
 
     def __len__(self):
-        return len(self.data)
\ No newline at end of file
+        return len(self.data)
